@@ -2,7 +2,9 @@
 #
 # SPDX-License-Identifier: CC0-1.0
 
-__version__ = '0.9.0'
+"""tgclients provide access to TextGrid services."""
+
+__version__ = '0.24.0'
 
 from tgclients.aggregator import (
     Aggregator,
@@ -16,28 +18,34 @@ from tgclients.config import (
 )
 from tgclients.crud import (
     TextgridCrud,
-    TextgridCrudRequest,
     TextgridCrudException,
+    TextgridCrudRequest,
 )
 from tgclients.metadata import (
     TextgridMetadata,
 )
+from tgclients.publish import (
+    TextgridPublish,
+)
 from tgclients.search import (
     TextgridSearch,
-    TextgridSearchRequest,
     TextgridSearchException,
+    TextgridSearchRequest,
 )
 from tgclients.utils import (
     Utils,
 )
+
 __all__ = [
     'Aggregator',
     'TextgridAuth',
-    'TextGridAuthException',
+    'TextgridAuthException',
     'TextgridConfig',
     'TextgridCrud',
     'TextgridCrudRequest',
     'TextgridCrudException',
+    'TextgridMetadata',
+    'TextgridPublish',
     'TextgridSearch',
     'TextgridSearchRequest',
     'TextgridSearchException',
