@@ -2,10 +2,11 @@
 #
 # SPDX-License-Identifier: LGPL-3.0-or-later
 
-"""Helper functions to work with TextGrid metadata XML"""
+"""Helper functions to work with TextGrid metadata XML."""
+
+import logging
 import os
 import re
-import logging
 from pathlib import Path
 from typing import Optional
 
@@ -13,8 +14,8 @@ from jinja2 import Environment, FileSystemLoader
 from xsdata.formats.dataclass.context import XmlContext
 from xsdata.formats.dataclass.parsers import XmlParser
 
-from tgclients.databinding.tgsearch import Response, ResultType
 from tgclients.databinding.textgrid_metadata_2010 import MetadataContainerType
+from tgclients.databinding.tgsearch import Response, ResultType
 
 try:
     import icu
@@ -23,11 +24,11 @@ except ImportError:
 
 logger = logging.getLogger(__name__)
 
-__location__ = os.path.realpath(
-    os.path.join(os.getcwd(), os.path.dirname(__file__)))
+__location__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(__file__)))
+
 
 class TextgridMetadata:
-    """Helper functions to work with TextGrid metadata XML"""
+    """Helper functions to work with TextGrid metadata XML."""
 
     def __init__(self):
         context = XmlContext()
@@ -35,10 +36,12 @@ class TextgridMetadata:
         self._file_extension_map = self._build_extension_map()
         if icu is not None:
             self._transliterator = self._create_transliterator()
+        else:
+            logger.warning('Transliterating without PyICU, you may need that for correct results')
 
     @staticmethod
     def create(title: str, mimetype: str) -> str:
-        """Create XML metadata for an TextGrid Object
+        """Create XML metadata for an TextGrid Object.
 
         Args:
             title (str): title of the object
@@ -48,14 +51,13 @@ class TextgridMetadata:
             str: XML metadata as string
         """
         path = Path(__file__).parent / 'templates'
-        env = Environment(
-            loader=FileSystemLoader(Path(path)), autoescape=True)
+        env = Environment(loader=FileSystemLoader(Path(path)), autoescape=True)
         template = env.get_template('metadata.xml.jinja2')
         metadata = template.render(title=title, format=mimetype)
         return metadata
 
     def build(self, title: str, mimetype: str) -> MetadataContainerType:
-        """Build metadata for an TextGrid Object
+        """Build metadata for an TextGrid Object.
 
         Args:
             title (str): title of the object
@@ -68,11 +70,20 @@ class TextgridMetadata:
         return self._parser.from_string(metadata, MetadataContainerType)
 
     def searchresponse2object(self, xml: str) -> Response:
+        """Build databinding for XML string returned from tgsearch.
+
+        Args:
+            xml (str): xml string as returned from tgsearch
+
+        Returns:
+            Response: tgsearch Response
+        """
         return self._parser.from_string(xml, Response)
 
     def filename_from_metadata(self, metadata: ResultType) -> str:
-        """Generate a filename for a textgrid search metadata result
-        containg title, textfgrid-uri and extension
+        """Generate a filename for a textgrid search metadata result.
+
+        This is made of title, textgrid-URI and extension.
 
         Args:
             metadata (ResultType): tgsearch metadata result
@@ -80,14 +91,17 @@ class TextgridMetadata:
         Returns:
             str: the filename
         """
-        title = metadata.object_value.generic.provided.title[0]
-        mimetype = metadata.object_value.generic.provided.format
+        if metadata.authorized is False:
+            title = 'Restricted TextGrid Object'
+            mimetype = None
+        else:
+            title = metadata.object_value.generic.provided.title[0]
+            mimetype = metadata.object_value.generic.provided.format
         uri = metadata.object_value.generic.generated.textgrid_uri.value
         return self.filename(title, uri, mimetype)
 
     def filename(self, title: str, tguri: str, mimetype: str) -> str:
-        """Generate a filename for the triple of
-        title, textfgrid-uri and extension
+        """Generate a filename for the triple of title, textfgrid-uri and extension.
 
         Args:
             title (str): the title
@@ -109,8 +123,7 @@ class TextgridMetadata:
         # converted to python from info.textgrid.utils.export.filenames.FileExtensionMap
         # of link-rewriter (https://gitlab.gwdg.de/dariah-de/textgridrep/link-rewriter)
         extension_map = {}
-        map_line_pattern = re.compile(
-            '^[ \t]*([^# \t]+)[ \t]*([^#]+)[ \t]*(#.*)?$')
+        map_line_pattern = re.compile('^[ \t]*([^# \t]+)[ \t]*([^#]+)[ \t]*(#.*)?$')
         space_pattern = re.compile('[ \t]+')
 
         with open(os.path.join(__location__, 'mime.types'), encoding='utf8') as mimefile:
@@ -128,6 +141,7 @@ class TextgridMetadata:
 
     def extension_for_format(self, mimetype: str) -> Optional[str]:
         """Find a matching extension for a textgrid mime type.
+
         The first matching extension for a mime type is returned, so
         extensions defined first in mime.types will be used.
 
@@ -136,7 +150,7 @@ class TextgridMetadata:
                             metadata format field (e.g. text/xml)
 
         Returns:
-            str: a filename extension
+            Optional[str]: a filename extension
         """
         if mimetype in self._file_extension_map:
             return self._file_extension_map[mimetype][0]
@@ -145,12 +159,22 @@ class TextgridMetadata:
 
     @staticmethod
     def remove_tg_prefix(tguri: str) -> str:
+        """Remove the 'textgrid:' prefix from an textgrid URI.
+
+        Args:
+            tguri (str): the textgrid URI
+
+        Returns:
+            str: uri without the prefix
+        """
         return tguri[9:]
 
     @staticmethod
     def id_from_filename(filename: str) -> str:
-        """extract the id from a filename which is named according to link rewriters
-        textgrid metadata to filename mapping
+        """Extract the id from a filename.
+
+        This is named according to link rewriters
+        textgrid metadata to filename mapping.
 
         Args:
             filename (str): the filename
@@ -162,7 +186,7 @@ class TextgridMetadata:
         next_to_last_dot = filename.rfind('.', 0, last_dot)
         # a textgrid uri has a revision number in the end.
         # if the chars after the last dot are not numeric, we have a filename extension
-        if not filename[last_dot+1:].isnumeric():
+        if not filename[last_dot + 1 :].isnumeric():
             # extension is there? we need the '.' before the dot separating the uri
             # from the revision component
             next_to_last_dot = filename.rfind('.', 0, next_to_last_dot)
@@ -170,10 +194,10 @@ class TextgridMetadata:
             # there is no extension to cut of, we want the end of the string
             last_dot = None
 
-        return filename[next_to_last_dot+1:last_dot]
+        return filename[next_to_last_dot + 1 : last_dot]
 
     def transliterate(self, title: str) -> str:
-        """replace all chars which may be problematic in filenames from title string
+        """Replace all chars which may be problematic in filenames from title string.
 
         Args:
             title (str): a title from textgrid metadata
@@ -183,7 +207,6 @@ class TextgridMetadata:
         """
         name: str = ''
         if icu is None:
-            logger.warning('Transliterating without PyICU, you may need that for correct results')
             name = title.replace(' ', '_').replace(']', '_').replace('[', '_').replace(':', '_')
         else:
             name = self._transliterator.transliterate(title)
@@ -194,4 +217,5 @@ class TextgridMetadata:
         with open(os.path.join(__location__, 'tgfilenames.rules'), encoding='utf8') as rulesfile:
             rules = rulesfile.read()
             return icu.Transliterator.createFromRules(
-                'TgFilenames', rules, icu.UTransDirection.FORWARD)
+                'TgFilenames', rules, icu.UTransDirection.FORWARD
+            )
